=========================
The Physics Vector Module
=========================

.. topic:: Abstract

   In this documentation the components of the sympy.physics.vector module
   have been discussed. :mod:`vector` has been written to facilitate the
   operations pertaining to 3-dimensional vectors, as functions of time or
   otherwise, in sympy.physics.


References for Physics/Vector
================================

.. [WikiDyadics] "Dyadics." Wikipedia, the Free Encyclopedia. Web. 05 Aug.
        2011. <http://en.wikipedia.org/wiki/Dyadics>.
.. [WikiDyadicProducts] "Dyadic Product." Wikipedia, the Free Encyclopedia.
        Web. 05 Aug. 2011. <http://en.wikipedia.org/wiki/Dyadic_product>.
.. [Likins1973] Likins, Peter W. Elements of Engineering Mechanics.
        McGraw-Hill, Inc. 1973. Print.

Guide to Vector
===============

.. toctree::
    :maxdepth: 2

    vectors.rst
    kinematics.rst
    advanced.rst
    fields.rst

Vector API
==========

.. toctree::
    :maxdepth: 2

    api/classes.rst
    api/kinematics.rst
    api/printing.rst
    api/functions.rst
    api/fieldfunctions.rst
